pub struct SecretReference { /* private fields */ }Expand description
Reference to a secret in a secret provider.
This struct is used to identify secrets without containing the actual secret value. It consists of a secret reference string and an optional provider name.
Example
use regent_sdk::secrets::SecretReference;
// Reference to a secret in the default provider
let ref1 = SecretReference::from("my_secret", None);
// Reference to a secret in a specific provider
let ref2 = SecretReference::from("my_secret", Some("aws".to_string()));Implementations
Sourceimpl SecretReference
impl SecretReference
Sourcepub fn from(sec_ref: &str, provider: Option<String>) -> Self
pub fn from(sec_ref: &str, provider: Option<String>) -> Self
Create a new secret reference.
Arguments
sec_ref- The reference/identifier for the secretprovider- Optional name of the secret provider
Example
use regent_sdk::secrets::SecretReference;
// Use default provider
let ref1 = SecretReference::from("password", None);
// Use specific provider
let ref2 = SecretReference::from("api_key", Some("aws".to_string()));Trait Implementations
Sourceimpl Clone for SecretReference
impl Clone for SecretReference
Sourcefn clone(&self) -> SecretReference
fn clone(&self) -> SecretReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecretReference
impl Debug for SecretReference
Sourceimpl<'de> Deserialize<'de> for SecretReference
impl<'de> Deserialize<'de> for SecretReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SecretReference
impl PartialEq for SecretReference
Sourceimpl Serialize for SecretReference
impl Serialize for SecretReference
impl StructuralPartialEq for SecretReference