pub struct UserBlockExpectedState { /* private fields */ }Expand description
Configuration for a user account
Use the builder pattern to create and manage user accounts with various properties. When state is Present, you can specify user properties like UID, shell, home directory, etc. When state is Absent, the user will be removed (and optionally their home directory).
The append field controls whether supplementary groups are appended to existing groups
or replaced entirely.
Implementations
Sourceimpl UserBlockExpectedState
impl UserBlockExpectedState
pub fn absent( &mut self, username: &str, remove_home: Option<bool>, ) -> UserBlockExpectedState
pub fn present_with_defaults(username: &str) -> UserBlockExpectedState
pub fn present_with_details( username: &str, details: UserDetails, ) -> UserBlockExpectedState