pub struct LineInFileBlockExpectedState { /* private fields */ }Expand description
Configuration for managing a line in a file
Implementations
Sourceimpl LineInFileBlockExpectedState
impl LineInFileBlockExpectedState
Sourcepub fn absent(
file_path: &str,
line: Line,
file_must_exist_anyway: bool,
) -> LineInFileBlockExpectedState
pub fn absent( file_path: &str, line: Line, file_must_exist_anyway: bool, ) -> LineInFileBlockExpectedState
Creates a block for a line that should not exist in the file.
file_path: Path to the file.line: The line (or pattern) to ensure is absent.file_must_exist_anyway: Iftrue, the file must exist (but the line must not). Iffalse, the file may not exist (and the line is trivially absent).
Sourcepub fn present_at_top(
file_path: &str,
line: Line,
create: Option<bool>,
) -> LineInFileBlockExpectedState
pub fn present_at_top( file_path: &str, line: Line, create: Option<bool>, ) -> LineInFileBlockExpectedState
Creates a block for a line that should exist at the top of the file.
file_path: Path to the file.line: The line to insert (or ensure exists).create: Iftrue, the file will be created if it doesn’t exist.
Sourcepub fn present_at_bottom(
file_path: &str,
line: Line,
create: Option<bool>,
) -> LineInFileBlockExpectedState
pub fn present_at_bottom( file_path: &str, line: Line, create: Option<bool>, ) -> LineInFileBlockExpectedState
Creates a block for a line that should exist at the bottom of the file.
file_path: Path to the file.line: The line to insert (or ensure exists).create: Iftrue, the file will be created if it doesn’t exist.
Sourcepub fn present_after(
file_path: &str,
line: Line,
insert_after: &str,
firstmatch: Option<bool>,
create: Option<bool>,
) -> LineInFileBlockExpectedState
pub fn present_after( file_path: &str, line: Line, insert_after: &str, firstmatch: Option<bool>, create: Option<bool>, ) -> LineInFileBlockExpectedState
Creates a block for a line that should exist after a specific pattern.
file_path: Path to the file.line: The line to insert (or ensure exists).insert_after: The pattern to match (e.g., a regex or literal string).firstmatch: Iftrue, use the first match ofinsert_after. Iffalse, use the last match.create: Iftrue, the file will be created if it doesn’t exist.
Sourcepub fn present_before(
file_path: &str,
line: Line,
insert_before: &str,
firstmatch: Option<bool>,
create: Option<bool>,
) -> LineInFileBlockExpectedState
pub fn present_before( file_path: &str, line: Line, insert_before: &str, firstmatch: Option<bool>, create: Option<bool>, ) -> LineInFileBlockExpectedState
Creates a block for a line that should exist before a specific pattern.
file_path: Path to the file.line: The line to insert (or ensure exists).insert_before: The pattern to match (e.g., a regex or literal string).firstmatch: Iftrue, use the first match ofinsert_before. Iffalse, use the last match.create: Iftrue, the file will be created if it doesn’t exist.
Sourcepub fn present_anywhere(
file_path: &str,
line: Line,
create: Option<bool>,
) -> LineInFileBlockExpectedState
pub fn present_anywhere( file_path: &str, line: Line, create: Option<bool>, ) -> LineInFileBlockExpectedState
Creates a block for a line that should exist somewhere in the file (no position constraint).
file_path: Path to the file.line: The line to ensure exists.create: Iftrue, the file will be created if it doesn’t exist.
Sourcepub fn raw_line(content: Parameter<String>) -> Line
pub fn raw_line(content: Parameter<String>) -> Line
Helper to create a Line::Raw from a string.
Sourcepub fn regexp_line(pattern: &str) -> Line
pub fn regexp_line(pattern: &str) -> Line
Helper to create a Line::Regexp from a regex pattern.
Sourcepub fn regexp_with_backrefs_line(regexp: &str, content_to_insert: &str) -> Line
pub fn regexp_with_backrefs_line(regexp: &str, content_to_insert: &str) -> Line
Helper to create a Line::RegexpWithBackrefs from a regex and replacement.
Sourcepub fn search_string_line(pattern: &str) -> Line
pub fn search_string_line(pattern: &str) -> Line
Helper to create a Line::SearchString from a literal string.