pub enum Job {
Assess,
Reach,
}Expand description
The type of job for a RegentTask to perform.
Variants
Assess: Only assess compliance and return the current state (read-only)Reach: Assess compliance and automatically perform remediation to reach the expected state
Example
use regent_sdk::task::Job;
// For read-only compliance checking
let job = Job::Assess;
// For automatic remediation
let job = Job::Reach;Variants
Assess
Assess compliance only (read-only operation).
This will check if the host is compliant with the expected state and return the compliance status without making any changes.
Reach
Assess and remediate compliance (read-write operation).
This will check compliance and automatically perform the necessary remediations to bring the host into the expected state.