pub enum ServiceBlockExpectedState {
State {
name: String,
state: Option<ServiceExpectedState>,
enabled: bool,
},
Action {
name: String,
action: ServiceAction,
},
}Expand description
Configuration for a system service
This enum represents the desired state for a system service, supporting configurations:
State: Manage the service’s running state (started/stopped) and/or boot enablementAction: Manage unconditional actions (restart/reload)
YAML Representation
State with enabled:
Name: httpd
State: Started
Enabled: trueState only:
Name: nginx
State: StartedEnabled only:
Name: mysql
Enabled: trueAction only:
Name: nginx
Action: RestartedVariants
State
Manage the service’s running state and/or boot enablement
Note: The enabled field is only present in this variant to respect the semantics
that enabled state is managed alongside running state.
Fields

state: Option<ServiceExpectedState>Desired running state of the service (optional - can be omitted for enabled-only config)
Action
Manage unconditional actions (restart/reload)
Implementations
Sourceimpl ServiceBlockExpectedState
impl ServiceBlockExpectedState
Sourcepub fn state(
name: &str,
state: ServiceExpectedState,
enabled: bool,
) -> ServiceBlockExpectedState
pub fn state( name: &str, state: ServiceExpectedState, enabled: bool, ) -> ServiceBlockExpectedState
Create a state configuration with running state and boot enablement
Sourcepub fn enabled(name: &str, enabled: bool) -> ServiceBlockExpectedState
pub fn enabled(name: &str, enabled: bool) -> ServiceBlockExpectedState
Create an enabled-only configuration (no state management, only enablement)
Sourcepub fn restarted(name: &str) -> ServiceBlockExpectedState
pub fn restarted(name: &str) -> ServiceBlockExpectedState
Create a restarted action configuration
Sourcepub fn reloaded(name: &str) -> ServiceBlockExpectedState
pub fn reloaded(name: &str) -> ServiceBlockExpectedState
Create a reloaded action configuration